#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:           qubes-kernel-vm-support
Version:        4.2.15
Release:        1%{?dist}
Summary:        Qubes VM initramfs modules
Source0:        qubes-utils-%{version}.tar.gz

Group:          Qubes
Vendor:         Invisible Things Lab
License:        GPL v2 only
URL:            http://www.qubes-os.org

# qubes-prepare-vm-kernel interface version - to use in kernel.spec
Provides:       qubes-prepare-vm-kernel = 2
Requires:       dracut
Requires:       busybox
Requires:       e2fsprogs
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  e2fsprogs-devel
%if 0%{?is_opensuse}
# for directory ownership
BuildRequires: dracut
%endif

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%build
make -C kernel-modules all

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
%dir %{_prefix}/lib/qubes
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/lib/qubes/vm-modules-genfs
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub\.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Mon Dec 04 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils.git

* Mon Dec 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5df5616
- version 4.2.15

* Sun Dec 03 2023 Rusty Bird <rustybird@net-c.com> - 13a0ede
- qrexec-lib/pack: sanitize straight quotes in remote filenames

* Sat Dec 02 2023 Rusty Bird <rustybird@net-c.com> - 71f5b04
- qrexec-lib/pack: don't use curly quotes in error messages

* Mon Nov 13 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - b1e335a
- Avoid writing junk into Xenstore

* Sun Nov 05 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 24cdce9
- rpm: adjust dependencies for openSUSE

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad0b68b
- genfs: fix build/link flags

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bc62e92
- rpm: fix missing directory ownership

* Wed Sep 27 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 96698e2
- version 4.2.14

* Wed Sep 27 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - f89a3b8
- Block Zalgo text

* Sun Sep 24 2023 Rusty Bird <rustybird@net-c.com> - 3ee5516
- qrexec-lib/unpack: fail on EOF before end of transfer marker

* Sun Sep 17 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 3925e82
- Expose code point allowlist checking API

* Sun Sep 10 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6c4902e
- version 4.2.13

* Sun Aug 20 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6fe6fac
- version 4.2.12

* Wed Aug 16 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 711e416
- Drop unmaintained asynctest library

* Mon Aug 14 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 6f4f1ab
- Make qubes_pure_string_safe_for_display() usable

* Fri Aug 11 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 26c3e30
- debian: split libqubes-pure into separate package

* Fri Aug 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 65bc3f4
- Test rejection of codepoints past 0x10FFFFF

* Thu Aug 10 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 2cd3547
- Stricter symbolic link checks

* Thu Aug 10 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - b1c9bb6
- Link against just-built libqubes-pure

* Tue Jul 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d4c9805
- version 4.2.11

* Sat Jul 01 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 80efd31
- libqubes-pure: Add function for qube name validation

* Fri Jun 30 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - dbc5de5
- Add missing entries to .gitignore

* Fri Jun 30 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 91b2cf3
- version 4.2.10

* Mon Jun 26 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9efc9e3
- debian: reduce initramfs size

* Mon May 29 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 73a6d3a
- Update the character allowlist

* Mon May 29 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6c0246c
- version 4.2.9

* Tue May 23 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - d7b5bf9
- Allow meminfo-writer to create and use AF_UNIX stream sockets

* Mon May 22 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - a188c43
- initramfs: Handle the case where device-mapper is a module

* Fri May 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5acd9a2
- version 4.2.8

* Fri Apr 28 2023 Rusty Bird <rustybird@net-c.com> - c76eba0
- qubes-block: force logical block size 512 for loop device

* Wed Apr 26 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 30b68a9
- version 4.2.7

* Tue Apr 25 2023 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9945a12
- archlinux: support for new packaging in legacy builder

* Tue Apr 25 2023 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9d5f6e8
- Rework Archlinux packaging

* Mon Apr 17 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 755dc10
- qubes-block: Only destroy loop devices qubes-block created

* Mon Apr 17 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 0f8d664
- Fix multiple bugs in block script

* Fri Apr 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 17f4162
- ci: make git happy about source clone owned by a different user

* Fri Apr 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ed7a5e5
- Switch to new codecov uploader

* Mon Apr 10 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8af10c2
- version 4.2.6

* Sat Mar 18 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - d360a3d
- Write /dev/loopN to physical-device-path

* Sun Mar 12 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - e84bb22
- Respond to suggestions from code review

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 94066d9
- Always write "diskseq" entry

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - c25e4ed
- Avoid setting a size limit for the loop device

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - eb91a1d
- Add some static assertions

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 1694d8d
- deduplicate loop opening code

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 2d0088a
- Serialize loop device opening

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 98f06b4
- Work around bug in LOOP_CTL_GET_FREE

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 3131d57
- Clean up some error checks

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - edc7b41
- Retry LOOP_CONFIGURE as well as open

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - cd10495
- Always use permissive mode

* Sat Mar 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - e34df81
- Use different physical-device format for autoclear-enabled kernels

